##  Prerequisites
  * Jira Service Management:
    * Premium or Enterprise subscription for Jira Service Management
    * Account credentials with permissions to access Assets objects in Jira Service Management
  * SAP LeanIX: Administrator access to your workspace.
